/* ipt_ACCRATE.c account raitng module */

/* Copyright (c) 2011, TeamF1, Inc. */

/*
 * modification history:
 * ---------------------
 *  01a,25jul11,phb created
 */

/*
 * This module checks the individual interfaces' accounts created by ipt_account 
 * for the limit specified. If the limit specified is crossed then the packets
 * are dropped.
 * It has to be used with ipt_account only.
 */

#include <linux/module.h>
#include <linux/skbuff.h>
#include <linux/ip.h>
#include <net/checksum.h>

#include <linux/netfilter_ipv4/ip_tables.h>
#include <linux/netfilter_ipv4/ipt_ACCRATE.h>
#include <linux/netfilter_ipv4/ipt_account.h>

MODULE_LICENSE("Proprietary");
MODULE_AUTHOR("TeamF1");
MODULE_DESCRIPTION("iptables account rating module");

static unsigned int
target(struct sk_buff **pskb,
       const struct net_device *in,
       const struct net_device *out,
       unsigned int hooknum,
       const void *targinfo,
       void *userinfo)
{
	const struct ipt_accrate_target_info *accinfo = (struct ipt_accrate_target_info*)targinfo;
    char fileName[IPT_ACCRATE_NAME_SIZE];
    u_int32_t total = 0;
    u_int32_t limit = accinfo->limit;
    u_int32_t dir = accinfo->dir;

    strncpy(fileName, accinfo->file, sizeof(fileName));

    total = ipt_account_get_total (fileName, dir);

    if (total >= limit)
        return NF_DROP;

    return XT_CONTINUE;
}


static int
checkentry(const char *tablename,
	       const struct ipt_entry *e,
           void *targinfo,
           unsigned int targinfosize,
           unsigned int hook_mask)
{
	const u_int32_t dir = ((struct ipt_accrate_target_info *)targinfo)->dir;
	const u_int32_t limit = ((struct ipt_accrate_target_info *)targinfo)->limit;
    
    if ((dir > 1) || (limit > 512000))  {
        printk(KERN_WARNING "ACCRATE: Bad value \n");
        return 0;
    }	
	return 1;
}

static struct ipt_target ipt_accrate_reg = {
	.name		= "ACCRATE",
	.target		= target,
	.checkentry	= checkentry,
	.me		= THIS_MODULE,
};

static int __init ipt_accrate_init(void)
{
	return ipt_register_target(&ipt_accrate_reg);
}

static void __exit ipt_accrate_fini(void)
{
	ipt_unregister_target(&ipt_accrate_reg);
}

module_init(ipt_accrate_init);
module_exit(ipt_accrate_fini);
